@@ -27,11 +27,11 @@ use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.11
+Version v1.2.0
 
 =cut
 
-our $VERSION = version->declare("v1.1.11");
+our $VERSION = version->declare("v1.2.0");
 
 # permit callers to sloppily pass undefined values
 sub BUILDARGS
@@ -54,7 +54,7 @@ has suite => (
 	isa      => Suite,
 	required => 1,
 	coerce   => 1,
-	default  => sub {'wheezy'},
+	default  => sub {'buster'},
 );
 
 has classdir => (
